@@ -1,22 +1,5 @@
 //
-// Copyright (c) 2018-2020 Bahtiar `kalkin-` Gadimov.
-//
-// This file is part of file-expert
-// (see https://github.com/kalkin/file-expert).
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Affero General Public License as
-// published by the Free Software Foundation, either version 3 of the
-// License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Affero General Public License for more details.
-//
-// You should have received a copy of the GNU Affero General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
+// $COPYRIGHT$: 794d8002d1b6d954e2302879cb69c215d893c60c
 use lazy_static::lazy_static;
 use std::collections::HashMap;
 
@@ -111,6 +94,7 @@ lazy_static! {
         (".inl".to_string(), "C++".to_string()),
         (".ino".to_string(), "C++".to_string()),
         (".ipp".to_string(), "C++".to_string()),
+        (".ixx".to_string(), "C++".to_string()),
         (".tcc".to_string(), "C++".to_string()),
         (".tpp".to_string(), "C++".to_string()),
         (".c-objdump".to_string(), "C-ObjDump".to_string()),
@@ -212,6 +196,7 @@ lazy_static! {
         (".eclxml".to_string(), "ECL".to_string()),
         (".ejs".to_string(), "EJS".to_string()),
         (".ect".to_string(), "EJS".to_string()),
+        (".ejs.t".to_string(), "EJS".to_string()),
         (".jst".to_string(), "EJS".to_string()),
         (".eq".to_string(), "EQ".to_string()),
         (".eb".to_string(), "Easybuild".to_string()),
@@ -275,6 +260,8 @@ lazy_static! {
         (".glslf".to_string(), "GLSL".to_string()),
         (".glslv".to_string(), "GLSL".to_string()),
         (".gshader".to_string(), "GLSL".to_string()),
+        (".rchit".to_string(), "GLSL".to_string()),
+        (".rmiss".to_string(), "GLSL".to_string()),
         (".tesc".to_string(), "GLSL".to_string()),
         (".tese".to_string(), "GLSL".to_string()),
         (".vert".to_string(), "GLSL".to_string()),
@@ -348,6 +335,7 @@ lazy_static! {
         (".xhtml".to_string(), "HTML".to_string()),
         (".ecr".to_string(), "HTML+ECR".to_string()),
         (".eex".to_string(), "HTML+EEX".to_string()),
+        (".html.heex".to_string(), "HTML+EEX".to_string()),
         (".html.leex".to_string(), "HTML+EEX".to_string()),
         (".erb".to_string(), "HTML+ERB".to_string()),
         (".erb.deface".to_string(), "HTML+ERB".to_string()),
@@ -604,7 +592,6 @@ lazy_static! {
         (".druby".to_string(), "Mirah".to_string()),
         (".duby".to_string(), "Mirah".to_string()),
         (".mirah".to_string(), "Mirah".to_string()),
-        (".mo".to_string(), "Modelica".to_string()),
         (".i3".to_string(), "Modula-3".to_string()),
         (".ig".to_string(), "Modula-3".to_string()),
         (".m3".to_string(), "Modula-3".to_string()),
@@ -742,6 +729,7 @@ lazy_static! {
         (".pde".to_string(), "Processing".to_string()),
         (".prolog".to_string(), "Prolog".to_string()),
         (".yap".to_string(), "Prolog".to_string()),
+        (".pml".to_string(), "Promela".to_string()),
         (".spin".to_string(), "Propeller Spin".to_string()),
         (".proto".to_string(), "Protocol Buffer".to_string()),
         (".pub".to_string(), "Public Key".to_string()),
@@ -978,6 +966,7 @@ lazy_static! {
         (".vdf".to_string(), "Valve Data Format".to_string()),
         (".veo".to_string(), "Verilog".to_string()),
         (".vim".to_string(), "Vim Script".to_string()),
+        (".vimrc".to_string(), "Vim Script".to_string()),
         (".vmb".to_string(), "Vim Script".to_string()),
         (".snip".to_string(), "Vim Snippet".to_string()),
         (".snippet".to_string(), "Vim Snippet".to_string()),
@@ -1028,6 +1017,7 @@ lazy_static! {
         (".glade".to_string(), "XML".to_string()),
         (".gmx".to_string(), "XML".to_string()),
         (".grxml".to_string(), "XML".to_string()),
+        (".hzp".to_string(), "XML".to_string()),
         (".iml".to_string(), "XML".to_string()),
         (".ivy".to_string(), "XML".to_string()),
         (".jelly".to_string(), "XML".to_string()),
