@@ -1,22 +1,5 @@
 //
-// Copyright (c) 2018-2020 Bahtiar `kalkin-` Gadimov.
-//
-// This file is part of file-expert
-// (see https://github.com/kalkin/file-expert).
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Affero General Public License as
-// published by the Free Software Foundation, either version 3 of the
-// License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Affero General Public License for more details.
-//
-// You should have received a copy of the GNU Affero General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
+// $COPYRIGHT$: 794d8002d1b6d954e2302879cb69c215d893c60c
 use lazy_static::lazy_static;
 use std::collections::HashMap;
 
@@ -40,7 +23,9 @@ lazy_static! {
             "Cloud Firestore Security Rules".to_string()
         ),
         ("Cakefile".to_string(), "CoffeeScript".to_string()),
+        ("Containerfile".to_string(), "Dockerfile".to_string()),
         ("Dockerfile".to_string(), "Dockerfile".to_string()),
+        ("Earthfile".to_string(), "Earthly".to_string()),
         (".editorconfig".to_string(), "EditorConfig".to_string()),
         ("mix.lock".to_string(), "Elixir".to_string()),
         (".abbrev_defs".to_string(), "Emacs Lisp".to_string()),
@@ -69,6 +54,7 @@ lazy_static! {
         ("go.mod".to_string(), "Go Module".to_string()),
         ("Jenkinsfile".to_string(), "Groovy".to_string()),
         ("haproxy.cfg".to_string(), "HAProxy".to_string()),
+        (".flake8".to_string(), "INI".to_string()),
         ("buildozer.spec".to_string(), "INI".to_string()),
         (".atomignore".to_string(), "Ignore List".to_string()),
         (".babelignore".to_string(), "Ignore List".to_string()),
@@ -250,6 +236,7 @@ lazy_static! {
         (".env".to_string(), "Shell".to_string()),
         (".env.example".to_string(), "Shell".to_string()),
         (".flaskenv".to_string(), "Shell".to_string()),
+        (".kshrc".to_string(), "Shell".to_string()),
         (".login".to_string(), "Shell".to_string()),
         (".profile".to_string(), "Shell".to_string()),
         (".zlogin".to_string(), "Shell".to_string()),
@@ -265,6 +252,7 @@ lazy_static! {
         ("bashrc".to_string(), "Shell".to_string()),
         ("cshrc".to_string(), "Shell".to_string()),
         ("gradlew".to_string(), "Shell".to_string()),
+        ("kshrc".to_string(), "Shell".to_string()),
         ("login".to_string(), "Shell".to_string()),
         ("man".to_string(), "Shell".to_string()),
         ("profile".to_string(), "Shell".to_string()),
@@ -273,6 +261,7 @@ lazy_static! {
         ("zprofile".to_string(), "Shell".to_string()),
         ("zshenv".to_string(), "Shell".to_string()),
         ("zshrc".to_string(), "Shell".to_string()),
+        (".shellcheckrc".to_string(), "ShellCheck Config".to_string()),
         ("Singularity".to_string(), "Singularity".to_string()),
         ("Android.bp".to_string(), "Soong".to_string()),
         ("BUCK".to_string(), "Starlark".to_string()),
@@ -288,6 +277,8 @@ lazy_static! {
         ("owh".to_string(), "Tcl".to_string()),
         ("starfield".to_string(), "Tcl".to_string()),
         ("AUTHORS".to_string(), "Text".to_string()),
+        ("CITATION".to_string(), "Text".to_string()),
+        ("CITATIONS".to_string(), "Text".to_string()),
         ("CHANGELOG".to_string(), "Text".to_string()),
         ("COPYING".to_string(), "Text".to_string()),
         ("COPYING.LESSER".to_string(), "Text".to_string()),
@@ -364,6 +355,7 @@ lazy_static! {
         (".clang-format".to_string(), "YAML".to_string()),
         (".clang-tidy".to_string(), "YAML".to_string()),
         (".gemrc".to_string(), "YAML".to_string()),
+        ("CITATION.cff".to_string(), "YAML".to_string()),
         ("glide.lock".to_string(), "YAML".to_string()),
         ("yarn.lock".to_string(), "YAML".to_string()),
         (".curlrc".to_string(), "cURL Config".to_string()),
