@@ -1,22 +1,5 @@
 //
-// Copyright (c) 2018-2020 Bahtiar `kalkin-` Gadimov.
-//
-// This file is part of file-expert
-// (see https://github.com/kalkin/file-expert).
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Affero General Public License as
-// published by the Free Software Foundation, either version 3 of the
-// License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Affero General Public License for more details.
-//
-// You should have received a copy of the GNU Affero General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
+// $COPYRIGHT$: 794d8002d1b6d954e2302879cb69c215d893c60c
 use fancy_regex::Regex;
 use lazy_static::lazy_static;
 
@@ -134,6 +117,7 @@ lazy_static! {
     static ref MICROSOFT_DEVELOPER_STUDIO_PROJECT_1: Regex = Regex::new(r#"# Microsoft Developer Studio Generated Build File"#).unwrap();
     static ref MODULA_2_1: Regex = Regex::new(r#"^\s*(?i:MODULE|END) [\w\.]+;"#).unwrap();
     static ref MOOCODE_1: Regex = Regex::new(r#"^\s*@\w+\s+"#).unwrap();
+    static ref MOTOKO: Regex = Regex::new(r#"\b(func|shared)\b"#).unwrap();
     static ref MUF_1: Regex = Regex::new(r#"^: "#).unwrap();
     static ref M_1: Regex = Regex::new(r#"^\s*;"#).unwrap();
     static ref NASL_1: Regex = Regex::new(r#"^\s*include\s*\(\s*(?:\"|')[\\/\w\-\.:\s]+\.(?:nasl|inc)\s*(?:\"|')\s*\)\s*;"#).unwrap();
@@ -849,6 +833,13 @@ pub fn linguist_heuristic(ext: &str, content: &[String]) -> Option<&'static str>
                 Some("AMPL")
             }
         }
+        ".mo" => {
+            if match_lines(&MOTOKO, content) {
+                Some("Motoko")
+            } else {
+                Some("Modelica")
+            }
+        }
         ".moo" => {
             if match_lines(&MOOCODE_1, content) {
                 Some("Moocode")
